<?php

namespace Drupal\payex_commerce\PluginForm\PayEx;

use Drupal\commerce_payment\PluginForm\PaymentMethodAddForm as BasePaymentMethodAddForm;
use Drupal\Core\Entity\Entity\EntityFormDisplay;
use Drupal\Core\Form\FormStateInterface;
use Drupal\profile\Entity\Profile;

/**
 * Class PaymentMethodAddForm
 *
 * Custom alterations for the PayEx integration with commerce.
 */
class PaymentMethodAddForm extends BasePaymentMethodAddForm {

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {

    /** @var \Drupal\commerce_payment\Entity\PaymentMethodInterface $payment_method */
    $payment_method = $this->entity;
    /** @var \Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\SupportsStoredPaymentMethodsInterface $payment_gateway_plugin */
    $payment_gateway_plugin = $this->plugin;
    $this->submitBillingProfileForm($form['billing_information'], $form_state);
    $form['billing_information']['#entity']->save();

    // We don't support configuration, so no need to bother with it.
    $payment_gateway_plugin->createPaymentMethod($payment_method, []);
  }

  /**
   * {@inheritdoc}
   */
  protected function buildBillingProfileForm(array $element, FormStateInterface $form_state) {
    /** @var \Drupal\commerce_payment\Entity\PaymentMethodInterface $payment_method */
    $payment_method = $this->entity;

    /** @var \Drupal\profile\Entity\ProfileInterface $billing_profile */
    $billing_profile = $payment_method->getBillingProfile();
    if (!$billing_profile) {
      $billing_profile = Profile::create([
        'type' => 'customer',
        'uid' => $payment_method->getOwnerId(),
      ]);
    }

    $form_display = EntityFormDisplay::collectRenderDisplay($billing_profile, 'default');
    $form_display->buildForm($billing_profile, $element, $form_state);
    // Remove the details wrapper from the address field.
    if (!empty($element['address']['widget'][0])) {
      $element['address']['widget'][0]['#type'] = 'container';
    }
    // Store the billing profile for the validate/submit methods.
    $element['#entity'] = $billing_profile;

    return $element;
  }

}
